@@ -1,10 +1,8 @@
-context("glmnet")
-
 test_that("glmnet + predict() works", {
   skip_on_cran()
   skip_if(do_not_run_glmnet)
   skip_if_not_installed("glmnet")
-  library(parsnip)
+  suppressPackageStartupMessages(library(parsnip))
   model <- logistic_reg(penalty = 10, mixture = 0.1) %>%
     set_engine("glmnet") %>%
     fit(as.factor(vs) ~ ., data = mtcars)
