@@ -46,13 +46,14 @@ test_that("mda + custom parsnip model + predict() works", {
       stop("`mode` should be 'classification'", call. = FALSE)
     }
     args <- list(sub_classes = rlang::enquo(sub_classes))
-    out <- list(args = args,
-                eng_args = NULL,
-                mode = mode,
-                method = NULL,
-                engine = NULL)
-    class(out) <- make_classes("mixture_da")
-    out
+    new_model_spec(
+      "mixture_da",
+      args = args,
+      eng_args = NULL,
+      mode = mode,
+      method = NULL,
+      engine = NULL
+    )
   }
   set_fit(
     model = "mixture_da",
@@ -65,6 +66,17 @@ test_that("mda + custom parsnip model + predict() works", {
       defaults = list()
     )
   )
+  set_encoding(
+    model = "mixture_da",
+    eng = "mda",
+    mode = "classification",
+    options = list(
+      predictor_indicators = "traditional",
+      compute_intercept = TRUE,
+      remove_intercept = TRUE,
+      allow_sparse_x = FALSE
+    )
+  )
   mda_fit <- mixture_da(sub_classes = 2) %>%
     set_engine("mda") %>%
     fit(Species ~ ., data = iris)
